@@ -6,6 +6,6 @@ ARGS="--sid=0x00000000 --uid1=0x1000007a --uid2=0x00000000 --uid3=0x00000000 --v
 
 wine $EPOCROOT/epoc32/tools/elf2e32.exe $ARGS --output=e32-ref.exe 
 ./elf2e32 $ARGS --output=e32-test.exe
-./bindiff e32-ref.exe e32-test.exe -i 0x14,0x18 -i 0x24,0x28
+./bindiff -i 0x14,0x18 -i 0x24,0x28 e32-ref.exe e32-test.exe
 rm e32-test.exe e32-ref.exe
 
