@@ -21,6 +21,7 @@
 #endif
 #include <iostream>
 #include <stdio.h>
+#include <stdlib.h>
 #include "parsepkg.h"
 #include "parsecmd.h"
 #include "crtsis.h"
@@ -2000,13 +2001,47 @@ BOOL CParsePkg::DoesExist(LPWSTR pszFile, DWORD *pdwSize)
 	BOOL fFound = FALSE;		
 	*pdwSize = 0;
 	
-	/* Convert to Unix filename */
-	LPWSTR tmp = pszFile;
+	/* Convert to Unix filename, do variable substitution */
+	WCHAR tempStr[MAX_PATH];
+	LPWSTR tmp = pszFile, out = tempStr;
 	while(*tmp) {
 		if(*tmp == '\\')
-			*tmp = '/';
+			*out++ = '/';
+		else if (*tmp == '$' && *(tmp + 1) == '(') {
+			char varName[MAX_PATH];
+			const char* var;
+			int i = 0;
+			tmp += 2;
+			while (*tmp && *tmp != ')')
+				varName[i++] = *tmp++;
+			varName[i++] = '\0';
+			var = getenv(varName);
+			if (!var) {
+				// Try an uppercase-only version of the env variable
+				char varNameUpper[MAX_PATH];
+				for (i = 0; varName[i]; i++)
+					varNameUpper[i] = toupper(varName[i]);
+				varNameUpper[i] = '\0';
+				var = getenv(varNameUpper);
+			}
+			if (var) {
+				i = 0;
+				while (var[i])
+					*out++ = var[i++];
+			} else {
+				printf("Environment variable %s not set, unable to substitute\n", varName);
+				*out++ = '$';
+				*out++ = '(';
+				while (varName[i])
+					*out++ = varName[i++];
+				*out++ = ')';
+			}
+		} else
+			*out++ = *tmp;
 		tmp++;
 	}
+	*out = '\0';
+	wcscpy(pszFile, tempStr);
 
 	try
 		{
