@@ -1,6 +1,6 @@
 /*
     Makesis 4
-    Copyright 2007 Martin Storsj
+    Copyright 2007 Martin Storsjo
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as
@@ -28,7 +28,7 @@
     you are not obliged to do so. If you do not wish to do so, delete this
     exception statement from your version.
 
-    Martin Storsj
+    Martin Storsjo
     martin@martin.st
 */
 
@@ -199,6 +199,10 @@ public:
 			uint32_t type = ReadUint32(aBuffer, aLength);
 			uint32_t length = ReadUint32(aBuffer, aLength);
 			SISField* field = NewObject(type);
+			if (!field) {
+				fprintf(stderr, "Bad input SIS file\n");
+				throw SISFieldBadSourceFile;
+			}
 			field->Load(aBuffer, length);
 			length += (4 - (length & 3)) & 3;
 			aBuffer += length;
@@ -234,7 +238,7 @@ public:
 			sum += iElements[i]->HeaderDataLength();
 		return sum;
 	}
-	virtual void AddElement(SISField* aField) {
+	virtual void AddElementAt(SISField* aField, uint32_t aPos) {
 		if (iNumElements == iArraySize) {
 			iArraySize *= 2;
 			SISField** newArray = new SISField*[iArraySize];
@@ -243,7 +247,12 @@ public:
 			delete [] iElements;
 			iElements = newArray;
 		}
-		iElements[iNumElements++] = aField;
+		memmove(&iElements[aPos+1], &iElements[aPos], sizeof(SISField*)*(iNumElements - aPos));
+		iElements[aPos] = aField;
+		iNumElements++;
+	}
+	virtual void AddElement(SISField* aField) {
+		AddElementAt(aField, iNumElements);
 	}
 	void CopyFieldData(uint8_t*& aPtr) const {
 		for (uint32_t i = 0; i < iNumElements; i++) {
@@ -282,7 +291,8 @@ public:
 		return NULL;
 	}
 	SISField* FindRemoveLastElement(uint32_t aType) {
-		for (uint32_t i = iNumElements-1; i >= 0; i--) {
+		// Signed, otherwise the loop won't ever terminate
+		for (int32_t i = iNumElements-1; i >= 0; i--) {
 			if (iElements[i]->Id() == aType) {
 				SISField* field = iElements[i];
 				for (uint32_t j = i; j < iNumElements-1; j++)
