@@ -1,6 +1,6 @@
 /*
     Makesis 4
-    Copyright 2007 Martin Storsj
+    Copyright 2007 Martin Storsjo
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as
@@ -28,7 +28,7 @@
     you are not obliged to do so. If you do not wish to do so, delete this
     exception statement from your version.
 
-    Martin Storsj
+    Martin Storsjo
     martin@martin.st
 */
 
@@ -730,7 +730,7 @@ void CSISFileGenerator::GenerateSISFile(const wchar_t* target, bool stub) {
 	if (siswriter->GetSelfsign()) {
 		initSigning();
 		try {
-			SISSignatureCertificateChain* chain = makeChain(controller, selfsignedCer, selfsignedKey, NULL);
+			SISSignatureCertificateChain* chain = makeChain(controller, selfsignedCer, strlen(selfsignedCer), selfsignedKey, strlen(selfsignedKey), NULL);
 			controller->AddElement(chain);
 		} catch (SignUtilError err) {
 			throw ErrCantSign;
