@@ -3,7 +3,7 @@
 // Copyright (c) 1997-1999 Symbian Ltd.  All rights reserved.
 //
 
-#include <iostream.h>
+#include <iostream>
 #include <stdlib.h>
 #include "mem.h"
 
