@@ -5,6 +5,7 @@
 
 #include <assert.h>
 #include <string.h>
+#include <stdlib.h>
 #include <astring.h>
 #include "rcbinstr.h"
 #include "tokens.h"
@@ -12,6 +13,8 @@
 #include "numval.h"
 #include "datatype.h"
 
+using namespace std;
+
 extern long CurrentId;
 extern RCTypeArray gTypes;
 
